@@ -9,8 +9,9 @@ import pytest
 from kafka.structs import TopicPartition
 from kafka.coordinator.assignors.range import RangePartitionAssignor
 from kafka.coordinator.assignors.roundrobin import RoundRobinPartitionAssignor
-from kafka.coordinator.assignors.sticky.sticky_assignor import StickyPartitionAssignor, StickyAssignorUserDataV1
-from kafka.coordinator.protocol import ConsumerProtocolMemberAssignment, ConsumerProtocolMemberMetadata
+from kafka.coordinator.assignors.sticky.sticky_assignor import StickyPartitionAssignor
+from kafka.coordinator.protocol import ConsumerProtocolMemberAssignment_v0
+from kafka.coordinator.subscription import Subscription
 from kafka.vendor import six
 
 
@@ -34,17 +35,17 @@ def create_cluster(mocker, topics, topics_partitions=None, topic_partitions_lamb
 def test_assignor_roundrobin(mocker):
     assignor = RoundRobinPartitionAssignor
 
-    member_metadata = {
-        'C0': assignor.metadata({'t0', 't1'}),
-        'C1': assignor.metadata({'t0', 't1'}),
+    group_subscriptions = {
+        'C0': Subscription(assignor.metadata({'t0', 't1'}), None),
+        'C1': Subscription(assignor.metadata({'t0', 't1'}), None),
     }
 
     cluster = create_cluster(mocker, {'t0', 't1'}, topics_partitions={0, 1, 2})
-    ret = assignor.assign(cluster, member_metadata)
+    ret = assignor.assign(cluster, group_subscriptions)
     expected = {
-        'C0': ConsumerProtocolMemberAssignment(
+        'C0': ConsumerProtocolMemberAssignment_v0(
             assignor.version, [('t0', [0, 2]), ('t1', [1])], b''),
-        'C1': ConsumerProtocolMemberAssignment(
+        'C1': ConsumerProtocolMemberAssignment_v0(
             assignor.version, [('t0', [1]), ('t1', [0, 2])], b'')
     }
     assert ret == expected
@@ -56,17 +57,17 @@ def test_assignor_roundrobin(mocker):
 def test_assignor_range(mocker):
     assignor = RangePartitionAssignor
 
-    member_metadata = {
-        'C0': assignor.metadata({'t0', 't1'}),
-        'C1': assignor.metadata({'t0', 't1'}),
+    group_subscriptions = {
+        'C0': Subscription(assignor.metadata({'t0', 't1'}), None),
+        'C1': Subscription(assignor.metadata({'t0', 't1'}), None),
     }
 
     cluster = create_cluster(mocker, {'t0', 't1'}, topics_partitions={0, 1, 2})
-    ret = assignor.assign(cluster, member_metadata)
+    ret = assignor.assign(cluster, group_subscriptions)
     expected = {
-        'C0': ConsumerProtocolMemberAssignment(
+        'C0': ConsumerProtocolMemberAssignment_v0(
             assignor.version, [('t0', [0, 1]), ('t1', [0, 1])], b''),
-        'C1': ConsumerProtocolMemberAssignment(
+        'C1': ConsumerProtocolMemberAssignment_v0(
             assignor.version, [('t0', [2]), ('t1', [2])], b'')
     }
     assert ret == expected
@@ -102,9 +103,9 @@ def test_sticky_assignor1(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C0': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t0', [0]), ('t1', [1]), ('t3', [0])], b''),
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t0', [1]), ('t2', [0]), ('t3', [1])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0]), ('t2', [1])], b''),
+        'C0': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t0', [0]), ('t1', [1]), ('t3', [0])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t0', [1]), ('t2', [0]), ('t3', [1])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0]), ('t2', [1])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -115,10 +116,10 @@ def test_sticky_assignor1(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C0': ConsumerProtocolMemberAssignment(
+        'C0': ConsumerProtocolMemberAssignment_v0(
             StickyPartitionAssignor.version, [('t0', [0]), ('t1', [1]), ('t2', [0]), ('t3', [0])], b''
         ),
-        'C2': ConsumerProtocolMemberAssignment(
+        'C2': ConsumerProtocolMemberAssignment_v0(
             StickyPartitionAssignor.version, [('t0', [1]), ('t1', [0]), ('t2', [1]), ('t3', [1])], b''
         ),
     }
@@ -158,9 +159,9 @@ def test_sticky_assignor2(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C0': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t0', [0])], b''),
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0, 1])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t2', [0, 1, 2])], b''),
+        'C0': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t0', [0])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0, 1])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t2', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -171,8 +172,8 @@ def test_sticky_assignor2(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t0', [0]), ('t1', [0, 1])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t2', [0, 1, 2])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t0', [0]), ('t1', [0, 1])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t2', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -187,7 +188,7 @@ def test_sticky_one_consumer_no_topic(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -202,7 +203,7 @@ def test_sticky_one_consumer_nonexisting_topic(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -217,7 +218,7 @@ def test_sticky_one_consumer_one_topic(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -232,7 +233,7 @@ def test_sticky_should_only_assign_partitions_from_subscribed_topics(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -247,7 +248,7 @@ def test_sticky_one_consumer_multiple_topics(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0, 1, 2]), ('t2', [0, 1, 2])], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0, 1, 2]), ('t2', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -263,8 +264,8 @@ def test_sticky_two_consumers_one_topic_one_partition(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -280,8 +281,8 @@ def test_sticky_two_consumers_one_topic_two_partitions(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [1])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [1])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -299,9 +300,9 @@ def test_sticky_multiple_consumers_mixed_topic_subscriptions(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0, 2])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t2', [0, 1])], b''),
-        'C3': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [1])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0, 2])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t2', [0, 1])], b''),
+        'C3': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [1])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -316,7 +317,7 @@ def test_sticky_add_remove_consumer_one_topic(mocker):
 
     assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
     }
     assert_assignment(assignment, expected_assignment)
 
@@ -356,8 +357,8 @@ def test_sticky_add_remove_topic_two_consumers(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0, 2])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [1])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0, 2])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [1])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -371,8 +372,8 @@ def test_sticky_add_remove_topic_two_consumers(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0, 2]), ('t2', [1])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [1]), ('t2', [0, 2])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0, 2]), ('t2', [1])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [1]), ('t2', [0, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -386,8 +387,8 @@ def test_sticky_add_remove_topic_two_consumers(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C1': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t2', [1])], b''),
-        'C2': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t2', [0, 2])], b''),
+        'C1': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t2', [1])], b''),
+        'C2': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t2', [0, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -601,7 +602,7 @@ def test_assignment_updated_for_deleted_topic(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t1', [0]), ('t3', list(range(100)))], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t1', [0]), ('t3', list(range(100)))], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -616,7 +617,7 @@ def test_no_exceptions_when_only_subscribed_topic_is_deleted(mocker):
 
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [('t', [0, 1, 2])], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
@@ -630,7 +631,7 @@ def test_no_exceptions_when_only_subscribed_topic_is_deleted(mocker):
     cluster = create_cluster(mocker, topics={}, topics_partitions={})
     sticky_assignment = StickyPartitionAssignor.assign(cluster, member_metadata)
     expected_assignment = {
-        'C': ConsumerProtocolMemberAssignment(StickyPartitionAssignor.version, [], b''),
+        'C': ConsumerProtocolMemberAssignment_v0(StickyPartitionAssignor.version, [], b''),
     }
     assert_assignment(sticky_assignment, expected_assignment)
 
